# Experimental module folder
This folder contains experimental modules. These modules are not supported by Cognite and are not guaranteed to work.

They are used to test new features and ideas. They may be removed at any time.
